@@ -1,7 +1,7 @@
 /*
  * cgiPAF.c     		
  *
- * Copyright (C) 2000-04 Staf Wagemakers Belgie/Belgium
+ * Copyright (C) 2000-14 Staf Wagemakers Belgie/Belgium
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -259,52 +259,17 @@ int main()
    /* test the new password if cracklib is enabled */
    
    if(enable_cracklib) {
-      	if ((cp=get_sg_item(config_file,CFGSECTION,CFG_CRACKLIB_DICTPATH))!=NULL) {
-	 	cracklib_dictpath=xmalloc(strlen(cp)+1);
-	 	strcpy(cracklib_dictpath,cp);
-	 	xfree(cp);
-	 	write_log(LOG_INFO,7,"cracklib_dictpath set to \"%s\"",cracklib_dictpath);
-      	}
 
-	/* vrfy that cracklib_dictpath is readable */
+      /* running Fascistcheck */
 
-      	if (cracklib_dictpath!=NULL) {
+      	char const * crack_msg;
+	write_log(LOG_INFO,7,"running FascistCheck");
 
-		char *full_cracklib_dictpath;
-		FILE *fp;
+	crack_msg = FascistCheck(newpass1,cracklib_dictpath);
 
-		full_cracklib_dictpath=xmalloc(strlen(cracklib_dictpath)+strlen(".pwi")+1);
+	write_log(LOG_INFO,7,"FascistCheck done");
 
-		strcpy(full_cracklib_dictpath,cracklib_dictpath);
-		strcat(full_cracklib_dictpath,".pwi");
-
-		if(!(fp=fopen(full_cracklib_dictpath,"r"))) {
-
-	 		write_log(LOG_INFO,6,"full_cracklib_dictpath \"%s\" is not readable clearing",full_cracklib_dictpath);
-			cracklib_dictpath=NULL;
-
-		}
-		else {
-
-			fclose(fp);
-
-		}
-
-
-      }
-
-      /* running Fascistcheck is cracklib_dictpath is not empty */
-
-      if (cracklib_dictpath!=NULL) {
-
-	 char const * crack_msg;
-	 write_log(LOG_INFO,7,"running FascistCheck");
-
-	 crack_msg = FascistCheck(newpass1,cracklib_dictpath);
-
-	 write_log(LOG_INFO,7,"FascistCheck done");
-
-	 if (0 != crack_msg) {
+	if (0 != crack_msg) {
 	    options[16][1]=(char *) xmalloc(strlen(crack_msg)+1);
 	    strcpy(options[16][1],crack_msg);
 	    options[21][1]=options[16][1];
@@ -313,11 +278,9 @@ int main()
 	    if (config_file!=NULL) fclose(config_file);   
 	    exit(0);
 	 }
-      }
-      else {
-	 write_log(LOG_INFO,4,"cracklib_dictpath not set, cracklib is disabled");
-      }
-   }
+
+	}
+
 
 #endif /* HAVE_CRACKLIB */
 
@@ -516,7 +479,7 @@ int main()
       		printf("<HR>\n");
       		printf("<P>\n");
       		printf("<FORM ACTION=\"/cgi-bin/mailcfg.cgi\" METHOD=\"POST\">\n");
-      		printf("<TABLE WIDTH=100%>\n");
+      		printf("<TABLE WIDTH=100%%>\n");
       		printf("<TR>\n");
       		printf("<TD>Login name: %s</TD>\n",options[0][1]);
       		printf("<TD ALIGN=\"LEFT\"><INPUT NAME=name VALUE=\"%s\" TYPE=HIDDEN SIZE=10 MAXLENGTH=15></TD>\n",options[0][1]);
